@@ -459,7 +459,11 @@ create function rdf_stmt_tbiup()
            if (new.object_lit is not null) then     
              select stmt_id into dummy from rdf_statement where 
 	       model_id = new.model_id and subject = new.subject and 
-	       predicate = new.predicate and object_lit = new.object_lit;
+	       predicate = new.predicate and object_lit = new.object_lit and 
+	       (object_lang = new.object_lang or 
+		 object_lang is null and new.object_lang is null) and 
+	       (object_type = new.object_type or 
+		 object_type is null and new.object_type is null) ;
              if (dummy is not null) then
 	       e = rdf_stmt_err2(tg_relname, tg_op, dummy);
              end if; 
@@ -580,43 +584,6 @@ create function rdf_stmt_get(integer,integer,integer,integer,integer)
     END;'
   language 'plpgsql';
 
--- create function rdf_stmt_get(integer,integer,text,
---   integer,text,integer,text,integer)
---   returns integer
---    /* $1: model id
---     * $2: subject namespace id
---     * $3: subject local name
---     * $4: predicate resource id
---     * $5: predicate local name
---     * $6: object namespace id
---     * $7: object local name
---     * $8: switch [0,1]
---     *       0 = do not create non-existing resources
---     *       1 = create non-existing resource (& namespaces)
---     * returns: new resource id or negative error message
---     *   -1: resource does not exists
---     * 
---     * no check for uniqueness (check is on other constraints)
---     */
---   as
---   ' DECLARE
---       rval integer;
---       subj integer;
---       pred integer;
---       obj integer;
---       dummy integer;
---     BEGIN
---       rval = -1;
---       subj = rdf_res_get($2,$3,$8);
---       pred = rdf_res_get($4,$5,$8);
---       obj = rdf_res_get($6,$7,$8);
---       if ((subj > 0) and (pred > 0) and (obj > 0)) then
---         rval = rdf_stmt_get($1,subj,pred,obj,$8);
---       end if;
---       return rval;
---     END;'
---   language 'plpgsql';
-
 create function rdf_stmt_get(integer,text,text,text,text,text,text,integer)
   returns integer
    /* $1: model id
@@ -672,55 +639,7 @@ create function rdf_stmt_new(integer,integer,integer,text, text, text)
     END;'
   language 'plpgsql';
 
--- create function rdf_stmt_new(integer,integer,text,
---   integer,text,text)
---   returns integer
---    /* $1: model id
---     * $2: subject namespace id
---     * $3: subject local name
---     * $4: predicate resource id
---     * $5: predicate local name
---     * $6: object literal
---     * returns: new resource id
---     * 
---     * no check (check is on other constraints)
---     */
---   as
---   ' DECLARE
---       subj integer;
---       pred integer;
---     BEGIN
---        subj = rdf_res_get($2,$3,1);
---        pred = rdf_res_get($4,$5,1);
---        return rdf_stmt_new($1,subj,pred,$6);
---     END;'
---   language 'plpgsql';
-
--- /*
--- create function rdf_stmt_new(integer,text,text,text,text,text)
---   returns integer
---    /* $1: model id
---     * $2: subject namespace
---     * $3: subject local name
---     * $4: predicate resource
---     * $5: predicate local name
---     * $6: object literal
---     * returns: new resource id
---     * 
---     * no check  for uniqueness (check is on other constraints)
---     */
---   as
---   ' DECLARE
---       subj integer;
---       pred integer;
---     BEGIN
---        subj = rdf_res_get($2,$3,1);
---        pred = rdf_res_get($4,$5,1);
---        return rdf_stmt_new($1,subj,pred,$6);
---     END;'
---   language 'plpgsql';
-
-create function rdf_stmt_get(integer,integer,integer,text,text,text,integer)
+create or replace function rdf_stmt_get(integer,integer,integer,text,text,text,integer)
   returns integer
   /* $1: model id
    * $2: subject resource id
@@ -741,7 +660,9 @@ create function rdf_stmt_get(integer,integer,integer,text,text,text,integer)
     BEGIN
       select stmt_id into rval from rdf_statement
         where model_id = $1 and subject = $2 and predicate = $3 and
-	      object_lit = $4;
+	  object_lit = $4 and 
+	  (object_lang = $5 or object_lang is null and $5 is null) and 
+	  (object_type = $6 or object_type is null and $6 is null) ;
       rval = coalesce(rval,-1);
       if ((rval = -1) and ($7 = 1)) then /* create new statement */
         rval = rdf_stmt_new($1,$2,$3,$4,$5,$6);
@@ -750,40 +671,6 @@ create function rdf_stmt_get(integer,integer,integer,text,text,text,integer)
     END;'
   language 'plpgsql';
 
--- create function rdf_stmt_get(integer,integer,text,
---   integer,text,text,integer)
---   returns integer
---    /* $1: model id
---     * $2: subject namespace id
---     * $3: subject local name
---     * $4: predicate resource id
---     * $5: predicate local name
---     * $6: object literal
---     * $7: switch [0,1]
---     *       0 = do not create non-existing resources
---     *       1 = create non-existing resource (& namespaces)
---     * returns: new resource id or negative error message
---     *   -1: resource does not exists
---     * 
---     * no check for uniqueness (check is on other constraints)
---     */
---   as
---   ' DECLARE
---       rval integer;
---       subj integer;
---       pred integer;
---     BEGIN
---       rval = -1;
---       subj = rdf_res_get($2,$3,$7);
---       pred = rdf_res_get($4,$5,$7);
---       if ((subj > 0) and (pred > 0)) then
---         rval = rdf_stmt_get($1,subj,pred,$6,$7);
---       end if;
---       return rval;
---     END;'
---   language 'plpgsql';
-  
-
 create function rdf_stmt_get(integer,text,text,text,text,text,text,text,
 	integer)
   returns integer
@@ -818,14 +705,14 @@ create function rdf_stmt_get(integer,text,text,text,text,text,text,text,
     END;'
   language 'plpgsql';
 
-create function rdf_stmt_del(integer,integer)
-  returns integer
-  as
-  'BEGIN
-     delete from rdf_statement where model_id = $1 and stmt_id = $2;
-     return 1;
-   END;'
-  language 'plpgsql';
+-- create function rdf_stmt_del(integer,integer)
+--   returns integer
+--   as
+--   'BEGIN
+--      delete from rdf_statement where model_id = $1 and stmt_id = $2;
+--      return 1;
+--    END;'
+--   language 'plpgsql';
 
 create function rdf_stmt_del(integer,integer,integer,integer)
   returns integer
@@ -838,52 +725,54 @@ create function rdf_stmt_del(integer,integer,integer,integer)
    END;'
   language 'plpgsql';
 
-create function rdf_stmt_del(integer,integer,integer,text)
+create function rdf_stmt_del(integer,integer,integer,text, text, text)
   returns integer
   as
   'BEGIN
      delete from rdf_statement where 
        model_id = $1 and 
-       subject = $2 and predicate = $3 and object_lit = $4;
+       subject = $2 and predicate = $3 and object_lit = $4 and 
+       (object_lang = $5 or object_lang is null and $5 is null) and 
+       (object_type = $6 or object_type is null and $6 is null);
      return 1; 
    END;'
   language 'plpgsql';
 
-create function rdf_stmt_del(integer,integer,text,integer,text,integer,text)
-  returns integer
-  as
-  'DECLARE
-     rval integer;
-     subj integer;
-     pred integer; 
-     obj integer;
-   BEGIN
-     subj = rdf_res_get($2,$3,0);
-     pred = rdf_res_get($4,$5,0);
-     obj = rdf_res_get($6,$7,0);
-     if ((subj > 0) and (pred > 0) and (obj > 0)) then
-       rval = rdf_stmt_del($1, subj,pred,obj);
-     end if;  
-     return rval; 
-   END;'
-  language 'plpgsql';
+-- create function rdf_stmt_del(integer,integer,text,integer,text,integer,text)
+--   returns integer
+--   as
+--   'DECLARE
+--      rval integer;
+--      subj integer;
+--      pred integer; 
+--      obj integer;
+--    BEGIN
+--      subj = rdf_res_get($2,$3,0);
+--      pred = rdf_res_get($4,$5,0);
+--      obj = rdf_res_get($6,$7,0);
+--      if ((subj > 0) and (pred > 0) and (obj > 0)) then
+--        rval = rdf_stmt_del($1, subj,pred,obj);
+--      end if;  
+--      return rval; 
+--    END;'
+--   language 'plpgsql';
 
-create function rdf_stmt_del(integer,integer,text,integer,text,text)
-  returns integer
-  as
-  'DECLARE
-     rval integer;
-     subj integer;
-     pred integer; 
-   BEGIN
-     subj = rdf_res_get($2,$3,0);
-     pred = rdf_res_get($4,$5,0);
-     if ((subj > 0) and (pred > 0)) then
-       rval = rdf_stmt_del($1, subj,pred,$6);
-     end if;  
-     return rval; 
-   END;'
-  language 'plpgsql';
+-- create function rdf_stmt_del(integer,integer,text,integer,text,text)
+--   returns integer
+--   as
+--   'DECLARE
+--      rval integer;
+--      subj integer;
+--      pred integer; 
+--    BEGIN
+--      subj = rdf_res_get($2,$3,0);
+--      pred = rdf_res_get($4,$5,0);
+--      if ((subj > 0) and (pred > 0)) then
+--        rval = rdf_stmt_del($1, subj,pred,$6);
+--      end if;  
+--      return rval; 
+--    END;'
+--   language 'plpgsql';
 
 
 create function rdf_stmt_del(integer,text,text,text,text,text,text)
@@ -905,7 +794,7 @@ create function rdf_stmt_del(integer,text,text,text,text,text,text)
    END;'
   language 'plpgsql';
 
-create function rdf_stmt_del(integer,text,text,text,text,text)
+create function rdf_stmt_del(integer,text,text,text,text,text,text,text)
   returns integer
   as
   'DECLARE
@@ -916,7 +805,7 @@ create function rdf_stmt_del(integer,text,text,text,text,text)
      subj = rdf_res_get($2,$3,0);
      pred = rdf_res_get($4,$5,0);
      if ((subj > 0) and (pred > 0)) then
-       rval = rdf_stmt_del($1, subj,pred,$6);
+       rval = rdf_stmt_del($1, subj,pred,$6, $7, $8);
      end if;  
      return rval; 
    END;'
@@ -1207,88 +1096,6 @@ create function rdf_cont_get(integer,text,text,text,text,integer,integer)
    END;'
   language 'plpgsql';
 
--- create function rdf_cont_add_item(integer,text,text,text,text,integer,text,text)
---   returns integer
---   /* add a new item to end of container items list
---    *
---    * $1: model id
---    * $2: subject namespace
---    * $3: subject local name
---    * $4: predicate namespace
---    * $5: predicate local name
---    * $6: container type
---    *	 1 = rdf:Bag
---    *	 2 = rdf:Sequence
---    *	 3 = rdf:Alternative
---    * $7: new item namespace
---    * $8: new item local name
---    * returns id of the new item resource
---    *
---    * Result in model is:
---    *  
---    * [subject] --[predicate]--> [container] --[rdf:_(next_id)]--> [new item]
---    *                                |
---    *                                 --[rdf:type]--> [rdf:(Bag|Seq|Alt)]
---    *  
---    * no check of already existing container type is erforced
---    */
---   as
---   'DECLARE
---      cont integer;
---      li integer;
---      subj integer;
---      pred integer;
---      obj integer;
---      dummy integer;
---    BEGIN
---      subj = rdf_cont_get($1,$2,$3,$4,$5,$6,1);
---      pred = rdf_res_get(rdfns(),rdf_cont_next_li($1,$2,$3,$4,$5),1);
---      obj = rdf_res_get($7,$8,1);
---      dummy = rdf_stmt_get($1,subj,pred,obj,1);
---      return obj;
---    END;'
---   language 'plpgsql';
-
--- create function rdf_cont_add_item(integer,text,text,text,text,integer,text)
---   returns integer
---   /* add new item to end of container items list
---    *
---    * $1: model id
---    * $2: subject namespace
---    * $3: subject local name
---    * $4: predicate namespace
---    * $5: predicate local name
---    * $6: container type
---    *	 1 = rdf:Bag
---    *	 2 = rdf:Sequence
---    *	 3 = rdf:Alternative
---    * $7: new literal item value
---    * returns id of the new statement
---    *
---    * Result in model is:
---    *  
---    * [subject] --[predicate]--> [container] --[rdf:_(next_id)]--> "new item"
---    *                                |
---    *                                 --[rdf:type]--> [rdf:(Bag|Seq|Alt)]
---    *  
---    * no check of already existing container type is erforced
---    */
---   as
---   'DECLARE
---      cont integer;
---      li integer;
---      subj integer;
---      pred integer;
---    BEGIN
---      subj = rdf_cont_get($1,$2,$3,$4,$5,$6,1);
---      pred = rdf_res_get(rdfns(),rdf_cont_next_li($1,$2,$3,$4,$5),1);
---      return rdf_stmt_get($1,subj,pred,$7,1);
---    END;'
---   language 'plpgsql';
-
-
--- /* ============================================================  */
-
 
 -- reification methods
 
